package com.company.backoffice.charge.test.mtd.rules;

import javax.enterprise.inject.spi.BeanManager;
import javax.inject.Inject;

import junit.framework.Assert;

import org.drools.builder.ResourceType;
import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.shrinkwrap.api.ArchivePaths;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.asset.EmptyAsset;
import org.jboss.shrinkwrap.api.spec.EnterpriseArchive;
import org.jboss.shrinkwrap.api.spec.JavaArchive;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.shrinkwrap.resolver.api.DependencyResolvers;
import org.jboss.shrinkwrap.resolver.api.maven.MavenDependencyResolver;
import org.jboss.shrinkwrap.resolver.api.maven.filter.ScopeFilter;
import org.junit.Test;

import com.company.backoffice.charge.common.rules.RulesBaseBuilder;
import com.company.backoffice.charge.common.rules.impl.RuleResource;
import com.company.backoffice.charge.common.rules.impl.RuleResourceBundle;
import com.company.backoffice.charge.test.mtd.AbstractBaseTest;

public class RuleCompilationTest extends AbstractBaseTest {

	public static JavaArchive getchargeCommon() {

		JavaArchive imported = DependencyResolvers
				.use(MavenDependencyResolver.class)
				.goOffline()
				.artifact(
						"com.company.t.charge:charge-common:0.0.1-SNAPSHOT")
				.resolveAs(JavaArchive.class).iterator().next();

		JavaArchive ja = ShrinkWrap
				.create(JavaArchive.class, "charge-common.jar")
				.merge(imported).addAsManifestResource("test-ds.xml");

		return ja;
	}

	@Deployment(order = 2, name = "build_ear")
	public static EnterpriseArchive buildTestableArchive() {

		WebArchive web = ShrinkWrap.create(WebArchive.class, "test-mtd.war")
				.addClasses(RuleCompilationTest.class, AbstractBaseTest.class)
				.addAsWebInfResource("beans.xml")
				.addAsWebInfResource("web.xml")
				.addAsManifestResource("MANIFEST.MF");
		ScopeFilter filter = new ScopeFilter("compile", "test");
		return ShrinkWrap
				.create(EnterpriseArchive.class, "charge-core-test.ear")
				.addAsLibraries(
						DependencyResolvers.use(MavenDependencyResolver.class)
								.includeDependenciesFromPom("pom.xml")
								.goOffline()
								.resolveAs(JavaArchive.class, filter))
				.addAsModule(web).addAsModule(getchargeCommon())
				.setApplicationXML("application.xml");

	}

	@Inject
	private RulesBaseBuilder rulesBaseBuilder;

	@Test
	public void testRulesBaseBuilderInjected() {
		/*
		 * Object ojb = beanManager.getBeans("rulesBaseBuilder");
		 * Assert.assertNotNull(ojb);
		 */
		Assert.assertNotNull(rulesBaseBuilder);
	}

	@Test
	public void testBaseFeeRulesCompiles() {
		RuleResourceBundle bundle = new RuleResourceBundle("test_BASE", null,
				new RuleResource("charge-language.dsl", ResourceType.DSL),
				new RuleResource("test-charge-schedule-rules.dslr",
						ResourceType.DSLR),
				new RuleResource("test-charge-surcharge-rules.dslr",
						ResourceType.DSLR), new RuleResource(
						"test-charge-base-tech-rules.drl", ResourceType.DRL),
				new RuleResource("test-charge-cap-tech-rules.drl",
						ResourceType.DRL));

		rulesBaseBuilder.generateKnowledgeBase(bundle);

	}

}
